@@ -1,5 +1,7 @@
 from perceiver.data.text import (
     BookCorpusDataModule,
+    BookCorpusOpenDataModule,
+    C4DataModule,
     Enwik8DataModule,
     ImdbDataModule,
     WikipediaDataModule,
